package com.ywt.mg.domain.entities;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * 数字营销-任务表
 */
@Entity
@Table(name = "marketing_project")
public class MarketingProject implements Serializable {
  private static final long serialVersionUID = 1L;

  /**
   * 主键id
   */
  @Id
  @Column(name = "id", insertable = false, nullable = false)
  private Integer id;

  /**
   * 任务编号
   */
  @Column(name = "biz_no", nullable = false)
  private String bizNo;

  /**
   * 任务名称
   */
  @Column(name = "name", nullable = false)
  private String name;

  /**
   * 任务类型IDs，比如：",1,3,"，对应 sys_dict_type_item 表ID
   */
  @Column(name = "project_type_ids", nullable = false)
  private String projectTypeIds = "";

  /**
   * 任务类型名称，对应 sys_dict_type_item 表（type_code：marketing_project_type） item_name
   */
  @Column(name = "project_type_name", nullable = false)
  private String projectTypeName = "";

  /**
   * 任务描述
   */
  @Column(name = "project_description", nullable = false)
  private String projectDescription;

  /**
   * 金额，格式：2k~4k、面谈等
   */
  @Column(name = "total")
  private String total = "";

  /**
   * 名额，如：100人
   */
  @Column(name = "places")
  private String places = "";

  /**
   * 性别要求ID，对应 sys_dict_type_item 表ID
   */
  @Column(name = "apply_gender_requirements_id")
  private Integer applyGenderRequirementsId;

  /**
   * 性别要求名称，对应 sys_dict_type_item 表（type_code：marketing_gender_requirements） item_name
   */
  @Column(name = "apply_gender_requirements_name")
  private String applyGenderRequirementsName = "";

  /**
   * 年龄要求，如：20岁≤年龄≤40岁
   */
  @Column(name = "apply_age_requirements")
  private String applyAgeRequirements = "";

  /**
   * 经验要求
   */
  @Column(name = "apply_experience_requirements")
  private String applyExperienceRequirements = "";

  /**
   * 学历要求ID，对应 sys_dict_type_item 表ID
   */
  @Column(name = "degree_type_id")
  private Integer degreeTypeId;

  /**
   * 学历要求名称，中间用","隔开，对应 sys_dict_type_item 表（type_code：marketing_degree_type） item_name
   */
  @Column(name = "degree_type_name")
  private String degreeTypeName = "";

  /**
   * 发布时间
   */
  @Column(name = "release_time")
  private Date releaseTime;

  /**
   * 截止时间
   */
  @Column(name = "end_time")
  private Date endTime;

  /**
   * 工作地点
   */
  @Column(name = "work_address")
  private String workAddress = "";

  /**
   * 工作方式ID，对应 sys_dict_type_item 表ID
   */
  @Column(name = "marketing_work_way_id")
  private Integer marketingWorkWayId;

  /**
   * 工作方式名称，对应 sys_dict_type_item 表（type_code：marketing_work_way） item_name
   */
  @Column(name = "marketing_work_way_name")
  private String marketingWorkWayName = "";

  /**
   * 工作时间ID，对应 sys_dict_type_item 表ID
   */
  @Column(name = "marketing_work_time_id")
  private Integer marketingWorkTimeId;

  /**
   * 工作时间名称，对应 sys_dict_type_item 表（type_code：marketing_work_time） item_name
   */
  @Column(name = "marketing_work_time_name")
  private String marketingWorkTimeName = "";

  /**
   * 任务周期-开始时间
   */
  @Column(name = "task_cycle_start")
  private Date taskCycleStart;

  /**
   * 任务周期-截止时间
   */
  @Column(name = "task_cycle_end")
  private Date taskCycleEnd;

  /**
   * 手机号
   */
  @Column(name = "mobile")
  private String mobile = "";

  /**
   * 备注
   */
  @Column(name = "remark")
  private String remark;

  /**
   * 是否需要认证资料，0-否，1-是
   */
  @Column(name = "need_certification")
  private Integer needCertification = 0;

  /**
   * 是否正常，0-正常，1-禁用
   */
  @Column(name = "status")
  private Integer status = 0;

  /**
   * 是否删除，0-否，1-是
   */
  @Column(name = "deleted", nullable = false)
  private Integer deleted = 0;

  /**
   * 创建时间
   */
  @Column(name = "create_time", nullable = false)
  private Date createTime;

  /**
   * 修改时间
   */
  @Column(name = "update_time", nullable = false)
  private Date updateTime;

  /**
   * 创建人id
   */
  @Column(name = "create_admin_id")
  private Integer createAdminId;

  /**
   * 创建人姓名
   */
  @Column(name = "create_admin_name")
  private String createAdminName;

  /**
   * 创建企业，对应health_enterprise表
   */
  @Column(name = "enterprise_id")
  private Integer enterpriseId;

  /**
   * 创建企业
   */
  @Column(name = "enterprise_name")
  private String enterpriseName;

  /**
   * 主键id
   */
  public Integer getId() {
    return id;
  }

  /**
   * 主键id
   */
  public void setId(Integer id) {
    this.id = id;
  }

  /**
   * 任务编号
   */
  public String getBizNo() {
    return bizNo;
  }

  /**
   * 任务编号
   */
  public void setBizNo(String bizNo) {
    this.bizNo = bizNo;
  }

  /**
   * 任务名称
   */
  public String getName() {
    return name;
  }

  /**
   * 任务名称
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * 任务类型IDs，比如：",1,3,"，对应 sys_dict_type_item 表ID
   */
  public String getProjectTypeIds() {
    return projectTypeIds;
  }

  /**
   * 任务类型IDs，比如：",1,3,"，对应 sys_dict_type_item 表ID
   */
  public void setProjectTypeIds(String projectTypeIds) {
    this.projectTypeIds = projectTypeIds;
  }

  /**
   * 任务类型名称，对应 sys_dict_type_item 表（type_code：marketing_project_type） item_name
   */
  public String getProjectTypeName() {
    return projectTypeName;
  }

  /**
   * 任务类型名称，对应 sys_dict_type_item 表（type_code：marketing_project_type） item_name
   */
  public void setProjectTypeName(String projectTypeName) {
    this.projectTypeName = projectTypeName;
  }

  /**
   * 任务描述
   */
  public String getProjectDescription() {
    return projectDescription;
  }

  /**
   * 任务描述
   */
  public void setProjectDescription(String projectDescription) {
    this.projectDescription = projectDescription;
  }

  /**
   * 金额，格式：2k~4k、面谈等
   */
  public String getTotal() {
    return total;
  }

  /**
   * 金额，格式：2k~4k、面谈等
   */
  public void setTotal(String total) {
    this.total = total;
  }

  /**
   * 名额，如：100人
   */
  public String getPlaces() {
    return places;
  }

  /**
   * 名额，如：100人
   */
  public void setPlaces(String places) {
    this.places = places;
  }

  /**
   * 性别要求ID，对应 sys_dict_type_item 表ID
   */
  public Integer getApplyGenderRequirementsId() {
    return applyGenderRequirementsId;
  }

  /**
   * 性别要求ID，对应 sys_dict_type_item 表ID
   */
  public void setApplyGenderRequirementsId(Integer applyGenderRequirementsId) {
    this.applyGenderRequirementsId = applyGenderRequirementsId;
  }

  /**
   * 性别要求名称，对应 sys_dict_type_item 表（type_code：marketing_gender_requirements） item_name
   */
  public String getApplyGenderRequirementsName() {
    return applyGenderRequirementsName;
  }

  /**
   * 性别要求名称，对应 sys_dict_type_item 表（type_code：marketing_gender_requirements） item_name
   */
  public void setApplyGenderRequirementsName(String applyGenderRequirementsName) {
    this.applyGenderRequirementsName = applyGenderRequirementsName;
  }

  /**
   * 年龄要求，如：20岁≤年龄≤40岁
   */
  public String getApplyAgeRequirements() {
    return applyAgeRequirements;
  }

  /**
   * 年龄要求，如：20岁≤年龄≤40岁
   */
  public void setApplyAgeRequirements(String applyAgeRequirements) {
    this.applyAgeRequirements = applyAgeRequirements;
  }

  /**
   * 经验要求
   */
  public String getApplyExperienceRequirements() {
    return applyExperienceRequirements;
  }

  /**
   * 经验要求
   */
  public void setApplyExperienceRequirements(String applyExperienceRequirements) {
    this.applyExperienceRequirements = applyExperienceRequirements;
  }

  /**
   * 学历要求ID，对应 sys_dict_type_item 表ID
   */
  public Integer getDegreeTypeId() {
    return degreeTypeId;
  }

  /**
   * 学历要求ID，对应 sys_dict_type_item 表ID
   */
  public void setDegreeTypeId(Integer degreeTypeId) {
    this.degreeTypeId = degreeTypeId;
  }

  /**
   * 学历要求名称，中间用","隔开，对应 sys_dict_type_item 表（type_code：marketing_degree_type） item_name
   */
  public String getDegreeTypeName() {
    return degreeTypeName;
  }

  /**
   * 学历要求名称，中间用","隔开，对应 sys_dict_type_item 表（type_code：marketing_degree_type） item_name
   */
  public void setDegreeTypeName(String degreeTypeName) {
    this.degreeTypeName = degreeTypeName;
  }

  /**
   * 发布时间
   */
  public Date getReleaseTime() {
    return releaseTime;
  }

  /**
   * 发布时间
   */
  public void setReleaseTime(Date releaseTime) {
    this.releaseTime = releaseTime;
  }

  /**
   * 截止时间
   */
  public Date getEndTime() {
    return endTime;
  }

  /**
   * 截止时间
   */
  public void setEndTime(Date endTime) {
    this.endTime = endTime;
  }

  /**
   * 工作地点
   */
  public String getWorkAddress() {
    return workAddress;
  }

  /**
   * 工作地点
   */
  public void setWorkAddress(String workAddress) {
    this.workAddress = workAddress;
  }

  /**
   * 工作方式ID，对应 sys_dict_type_item 表ID
   */
  public Integer getMarketingWorkWayId() {
    return marketingWorkWayId;
  }

  /**
   * 工作方式ID，对应 sys_dict_type_item 表ID
   */
  public void setMarketingWorkWayId(Integer marketingWorkWayId) {
    this.marketingWorkWayId = marketingWorkWayId;
  }

  /**
   * 工作方式名称，对应 sys_dict_type_item 表（type_code：marketing_work_way） item_name
   */
  public String getMarketingWorkWayName() {
    return marketingWorkWayName;
  }

  /**
   * 工作方式名称，对应 sys_dict_type_item 表（type_code：marketing_work_way） item_name
   */
  public void setMarketingWorkWayName(String marketingWorkWayName) {
    this.marketingWorkWayName = marketingWorkWayName;
  }

  /**
   * 工作时间ID，对应 sys_dict_type_item 表ID
   */
  public Integer getMarketingWorkTimeId() {
    return marketingWorkTimeId;
  }

  /**
   * 工作时间ID，对应 sys_dict_type_item 表ID
   */
  public void setMarketingWorkTimeId(Integer marketingWorkTimeId) {
    this.marketingWorkTimeId = marketingWorkTimeId;
  }

  /**
   * 工作时间名称，对应 sys_dict_type_item 表（type_code：marketing_work_time） item_name
   */
  public String getMarketingWorkTimeName() {
    return marketingWorkTimeName;
  }

  /**
   * 工作时间名称，对应 sys_dict_type_item 表（type_code：marketing_work_time） item_name
   */
  public void setMarketingWorkTimeName(String marketingWorkTimeName) {
    this.marketingWorkTimeName = marketingWorkTimeName;
  }

  /**
   * 任务周期-开始时间
   */
  public Date getTaskCycleStart() {
    return taskCycleStart;
  }

  /**
   * 任务周期-开始时间
   */
  public void setTaskCycleStart(Date taskCycleStart) {
    this.taskCycleStart = taskCycleStart;
  }

  /**
   * 任务周期-截止时间
   */
  public Date getTaskCycleEnd() {
    return taskCycleEnd;
  }

  /**
   * 任务周期-截止时间
   */
  public void setTaskCycleEnd(Date taskCycleEnd) {
    this.taskCycleEnd = taskCycleEnd;
  }

  /**
   * 手机号
   */
  public String getMobile() {
    return mobile;
  }

  /**
   * 手机号
   */
  public void setMobile(String mobile) {
    this.mobile = mobile;
  }

  /**
   * 备注
   */
  public String getRemark() {
    return remark;
  }

  /**
   * 备注
   */
  public void setRemark(String remark) {
    this.remark = remark;
  }

  /**
   * 是否需要认证资料，0-否，1-是
   */
  public Integer getNeedCertification() {
    return needCertification;
  }

  /**
   * 是否需要认证资料，0-否，1-是
   */
  public void setNeedCertification(Integer needCertification) {
    this.needCertification = needCertification;
  }

  /**
   * 是否正常，0-正常，1-禁用
   */
  public Integer getStatus() {
    return status;
  }

  /**
   * 是否正常，0-正常，1-禁用
   */
  public void setStatus(Integer status) {
    this.status = status;
  }

  /**
   * 是否删除，0-否，1-是
   */
  public Integer getDeleted() {
    return deleted;
  }

  /**
   * 是否删除，0-否，1-是
   */
  public void setDeleted(Integer deleted) {
    this.deleted = deleted;
  }

  /**
   * 创建时间
   */
  public Date getCreateTime() {
    return createTime;
  }

  /**
   * 创建时间
   */
  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  /**
   * 修改时间
   */
  public Date getUpdateTime() {
    return updateTime;
  }

  /**
   * 修改时间
   */
  public void setUpdateTime(Date updateTime) {
    this.updateTime = updateTime;
  }

  /**
   * 创建人id
   */
  public Integer getCreateAdminId() {
    return createAdminId;
  }

  /**
   * 创建人id
   */
  public void setCreateAdminId(Integer createAdminId) {
    this.createAdminId = createAdminId;
  }

  /**
   * 创建人姓名
   */
  public String getCreateAdminName() {
    return createAdminName;
  }

  /**
   * 创建人姓名
   */
  public void setCreateAdminName(String createAdminName) {
    this.createAdminName = createAdminName;
  }

  /**
   * 创建企业，对应health_enterprise表
   */
  public Integer getEnterpriseId() {
    return enterpriseId;
  }

  /**
   * 创建企业，对应health_enterprise表
   */
  public void setEnterpriseId(Integer enterpriseId) {
    this.enterpriseId = enterpriseId;
  }

  /**
   * 创建企业
   */
  public String getEnterpriseName() {
    return enterpriseName;
  }

  /**
   * 创建企业
   */
  public void setEnterpriseName(String enterpriseName) {
    this.enterpriseName = enterpriseName;
  }

  public String toString() {
    return "MarketingProject{id=" + id + 
      ", bizNo=" + bizNo + 
      ", name=" + name + 
      ", projectTypeIds=" + projectTypeIds + 
      ", projectTypeName=" + projectTypeName + 
      ", projectDescription=" + projectDescription + 
      ", total=" + total + 
      ", places=" + places + 
      ", applyGenderRequirementsId=" + applyGenderRequirementsId + 
      ", applyGenderRequirementsName=" + applyGenderRequirementsName + 
      ", applyAgeRequirements=" + applyAgeRequirements + 
      ", applyExperienceRequirements=" + applyExperienceRequirements + 
      ", degreeTypeId=" + degreeTypeId + 
      ", degreeTypeName=" + degreeTypeName + 
      ", releaseTime=" + releaseTime + 
      ", endTime=" + endTime + 
      ", workAddress=" + workAddress + 
      ", marketingWorkWayId=" + marketingWorkWayId + 
      ", marketingWorkWayName=" + marketingWorkWayName + 
      ", marketingWorkTimeId=" + marketingWorkTimeId + 
      ", marketingWorkTimeName=" + marketingWorkTimeName + 
      ", taskCycleStart=" + taskCycleStart + 
      ", taskCycleEnd=" + taskCycleEnd + 
      ", mobile=" + mobile + 
      ", remark=" + remark + 
      ", needCertification=" + needCertification + 
      ", status=" + status + 
      ", deleted=" + deleted + 
      ", createTime=" + createTime + 
      ", updateTime=" + updateTime + 
      ", createAdminId=" + createAdminId + 
      ", createAdminName=" + createAdminName + 
      ", enterpriseId=" + enterpriseId + 
      ", enterpriseName=" + enterpriseName + 
      "}";
  }
}